@@ -7,52 +7,73 @@ def checkrs(rs):
         return None
     else:
         return True
+    
+def getuser(user):
+    if type(user) in [str, int, list]:
+        if type(user) == list:
+            user = enumerate(user)
+            ids, usernames = [], []
+            for el in user:
+                if type(el[1]) == int:
+                    ids.append(el)
+                elif type(el[1]) == str:
+                    usernames.append(el)
+            newids, newusernames = [], []
+            if ids:
+                el = requests.post("https://users.roblox.com/v1/users", json={"userIds": [el[1] for el in ids], "excludeBannedUsers": False})
+                el = json.loads(el.text)
+                if el["data"]:
+                    for foo in el["data"]:
+                        newids.append(foo["id"])
+            if usernames:
+                el = requests.post("https://users.roblox.com/v1/usernames/users", json={"usernames": [el[1] for el in usernames], "excludeBannedUsers": False})
+                el = json.loads(el.text)
+                if el["data"]:
+                    for foo in el["data"]:
+                        newusernames.append(foo["id"])
+            user = sorted(newids + newusernames)
+            if user == []:
+                return None
+            else:
+                return user
+        else:
+            try:
+                user = int(user)
+            except:
+                pass
+            if type(user) == int:
+                el = requests.post("https://users.roblox.com/v1/users", json={"userIds": [user], "excludeBannedUsers": False})
+            else:
+                el = requests.post("https://users.roblox.com/v1/usernames/users", json={"usernames": [user], "excludeBannedUsers": False})
+            el = json.loads(el.text)
+            if el["data"] == []:
+                return None
+            else:
+                return el["data"][0]["id"]
+    else:
+        return None
 
 class client():
     def __init__(self, rosec=None):
-        self.User = _User(rosec)
-        self.Group = _Group(rosec)
+        self.user = _user(rosec)
+        self.group = _group(rosec)
 
 class _user():
     def __init__(self, rosec):
         self._rosec = rosec
     
     def check(self, user):
-        isint = True
-        try:
-            user = int(user)
-        except:
-            isint = None
-        if not isint:
-            el = requests.get("https://api.roblox.com/users/get-by-username", params={"username": user})
-            el = json.loads(el.text)
-            if "success" in el:
-                return el["errorMessage"]
-            else:
-                user = el["Id"]
-        el = requests.get(f"https://users.roblox.com/v1/users/{user}")
-        el = json.loads(el.text)
-        if "errors" not in el:
-            return {"exist": True}
+        user = getuser(user)
+        if user:
+            return True
         else:
-            return {"exist": False}
+            return False
     
     def info(self, user):
-        isint = True
-        try:
-            user = int(user)
-        except:
-            isint = None
-        if not isint:
-            el = requests.get("https://api.roblox.com/users/get-by-username", params={"username": user})
+        user = getuser(user)
+        if user:
+            el = requests.get(f"https://users.roblox.com/v1/users/{user}")
             el = json.loads(el.text)
-            if "success" in el:
-                return el["errorMessage"]
-            else:
-                user = el["Id"]
-        el = requests.get(f"https://users.roblox.com/v1/users/{user}")
-        el = json.loads(el.text)
-        if "data" not in el:
             foo = requests.get("https://thumbnails.roblox.com/v1/users/avatar", params={"userIds": user, "size": "720x720", "format": "png"})
             foo = json.loads(foo.text)
             bar = requests.get(f"https://friends.roblox.com/v1/users/{user}/friends/count")
@@ -73,88 +94,85 @@ class _user():
             }
             return info
         else:
-            return "That user doesn't exist"
+            return None
     
     def activity(self, user):
-        isint = True
-        try:
-            user = int(user)
-        except:
-            isint = None
-        if not isint:
-            el = requests.get("https://api.roblox.com/users/get-by-username", params={"username": user})
+        user = getuser(user)
+        if user:
+            yesrs = None
+            rosec = self._rosec
+            if rosec:
+                rscheck = checkrs(rosec)
+                if rscheck:
+                    yesrs = True
+                    el = requests.post("https://presence.roblox.com/v1/presence/users", json={"userIds": [user]}, cookies={".ROBLOSECURITY": rosec})
+                else:
+                    el = requests.post("https://presence.roblox.com/v1/presence/users", json={"userIds": [user]})
+            else:
+                el = requests.post("https://presence.roblox.com/v1/presence/users", json={"userIds": [user]})
             el = json.loads(el.text)
-            if "success" in el:
-                return el["errorMessage"]
+            if "errors" not in el:
+                el = el["userPresences"][0]
+                info = {}
+                if yesrs:
+                    if el["lastLocation"] not in ["", "Website"]:
+                        info["game"] = {
+                            "name": el["lastLocation"],
+                            "link": f"https://www.roblox.com/games/{el['placeId']}"
+                        }
+                if el["userPresenceType"] == 0:
+                    activitytype = "Offline"
+                elif el["userPresenceType"] == 1:
+                    activitytype = "Online"
+                elif el["userPresenceType"] == 2:
+                    activitytype = "In-Game"
+                else:
+                    activitytype = "Creating"
+                info["type"] = activitytype
+                return info
             else:
-                user = el["Id"]
-        params = {
-            "userIds": [
-                user
-            ]
-        }
-        yesrs = None
-        rosec = self._rosec
-        if rosec:
-            rscheck = checkrs(rosec)
-            if rscheck:
-                yesrs = True
-                el = requests.post("https://presence.roblox.com/v1/presence/users", json=params, cookies={".ROBLOSECURITY": rosec})
-            else:
-                el = requests.post("https://presence.roblox.com/v1/presence/users", json=params)
+                return el["errors"][0]["message"]
         else:
-            el = requests.post("https://presence.roblox.com/v1/presence/users", json=params)
-        el = json.loads(el.text)
-        if "errors" not in el:
-            el = el["userPresences"][0]
-            info = {}
-            if yesrs:
-                if el["lastLocation"] not in ["", "Website"]:
-                    info["game"] = {
-                        "name": el["lastLocation"],
-                        "link": f"https://www.roblox.com/games/{el['placeId']}"
+            return None
+
+    def friends(self, user):
+        user = getuser(user)
+        if user:
+            el = requests.get(f"https://friends.roblox.com/v1/users/{user}/friends")
+            el = json.loads(el.text)
+            if "errors" not in el:
+                info = {}
+                for foo in el["data"]:
+                    info[foo["name"]] = {
+                        "name": foo["name"],
+                        "id": foo["id"],
                     }
-            if el["userPresenceType"] == 0:
-                activitytype = "Offline"
-            elif el["userPresenceType"] == 1:
-                activitytype = "Online"
-            elif el["userPresenceType"] == 2:
-                activitytype = "In-Game"
+                return info
             else:
-                activitytype = "Creating"
-            info["type"] = activitytype
-            return info
+                return el["errors"][0]["message"]
         else:
-            return el["errors"][0]["message"]
+            return None
 
     def groups(self, user):
-        isint = True
-        try:
-            user = int(user)
-        except:
-            isint = None
-        if not isint:
-            el = requests.get("https://api.roblox.com/users/get-by-username", params={"username": user})
+        user = getuser(user)
+        if user:
+            el = requests.get(f"https://groups.roblox.com/v1/users/{user}/groups/roles")
             el = json.loads(el.text)
-            if "success" in el:
-                return el["errorMessage"]
-            else:
-                user = el["Id"]
-        el = requests.get(f"https://groups.roblox.com/v1/users/{user}/groups/roles")
-        el = json.loads(el.text)
-        if "errors" not in el:
-            info = {}
-            for foo in el["data"]:
-                info[foo["group"]["name"]] = {
-                    "Id": foo["group"]["id"],
-                    "Role": {
-                        "Name": foo["role"]["name"],
-                        "Id": foo["role"]["id"]
+            if "errors" not in el:
+                info = {}
+                for foo in el["data"]:
+                    info[foo["group"]["name"]] = {
+                        "id": foo["group"]["id"],
+                        "role": {
+                            "name": foo["role"]["name"],
+                            "id": foo["role"]["id"]
+                        }
                     }
-                }
-            return info
+                return info
+            else:
+                return el["errors"][0]["message"]
         else:
-            return el["errors"][0]["message"]
+            return None
 
 class _group():
     def __init__(self, rosec):
